#include <QtCore/QCoreApplication>
#include <QString>
#include <QDebug>
#include <qextserialport.h>

#ifdef _TTY_POSIX_
#define COMMUNICATIONS_PORT_BASE "/dev/ttyAMA0"                  //Base name for the virtual serial ports under Linux
#else
#define COMMUNICATIONS_PORT_BASE "\\\\.\\COM1"                  //Base name for the serial ports under Windows
#endif

int main(int argc, char *argv[])
{
    QextSerialPort *pTheSerialPort;                                 //Pointer to the serial port to write to
    char *pMessage = (char*) "Hello World\r\n";                     //Nice simple message to send out
    const int InBufferLength = 1;                                   //Length of the incoming buffer
    char pDataIn[InBufferLength];                                   //Buffer to hold an incoming character

    QCoreApplication a(argc, argv);                                 //Qt stuff necessary for underlying framework

    qDebug()<< COMMUNICATIONS_PORT_BASE;

    pTheSerialPort = new QextSerialPort(QString(COMMUNICATIONS_PORT_BASE));
    if(pTheSerialPort)
    {
        pTheSerialPort->setTimeout(0,1);                            //Set the timeouts to a minimum value
        pTheSerialPort->setBaudRate(BAUD57600);                     //Set the baud rate
        pTheSerialPort->setFlowControl(FLOW_OFF);                   //No flow control
        pTheSerialPort->setDataBits(DATA_8);                        //8 data bits
        pTheSerialPort->setStopBits(STOP_1);                        //1 stop bit
        pTheSerialPort->open(QIODevice::ReadWrite);                 //Open the port for read/write mode
        if(pTheSerialPort->isOpen())                                //Test to see if the port actually opened
        {
            pTheSerialPort->write(pMessage, strlen(pMessage));      //Write a message to the port
            while(pTheSerialPort->bytesAvailable() == 0)            //Wait for something to come back in
            {                                                       //Ya polling is bad, but this is supposed to be simple
            }
            pTheSerialPort->read(pDataIn, InBufferLength);          //Read one character in as an example
        }
        pTheSerialPort->close();                                    //Close the port
    }
    if(pTheSerialPort)                                              //Clean up
    {
        delete pTheSerialPort;
        pTheSerialPort = NULL;
    }

    return 0;

//    return a.exec();
}
